@@ -242,9 +242,9 @@ add_or_find_application (NautilusOpenWithDialog *dialog)
 
 
 	if (dialog->details->content_type) {
-		success = g_app_info_set_as_default_for_type (app,
-							      dialog->details->content_type,
-							      &error);
+		success = g_app_info_add_supports_type (app,
+							dialog->details->content_type,
+							&error);
 	} else {
 		success = g_app_info_set_as_default_for_extension (app,
 								   dialog->details->extension,
@@ -877,8 +877,7 @@ set_uri_and_type (NautilusOpenWithDialog *dialog,
 	char *label;
 	char *emname;
 	char *name, *extension;
-	
-	const char *description;
+	char *description;
 	
 	name = NULL;
 	extension = NULL;
@@ -907,10 +906,10 @@ set_uri_and_type (NautilusOpenWithDialog *dialog,
 		description = g_content_type_get_description (mime_type);
 
 		if (description == NULL) {
-			description = _("Unknown");
+			description = g_strdup (_("Unknown"));
 		}
 
-		dialog->details->type_description = g_strdup (description);
+		dialog->details->type_description = description;
 	}
 	g_free (extension);
 
