@@ -136,6 +136,7 @@ nautilus_navigation_window_initialize_toolbars (NautilusNavigationWindow *window
 static GList *
 get_extension_toolbar_items (NautilusNavigationWindow *window)
 {
+	NautilusWindowSlot *slot;
 	GList *items;
 	GList *providers;
 	GList *l;
@@ -143,6 +144,8 @@ get_extension_toolbar_items (NautilusNavigationWindow *window)
 	providers = nautilus_module_get_extensions_for_type (NAUTILUS_TYPE_MENU_PROVIDER);
 	items = NULL;
 
+	slot = NAUTILUS_WINDOW (window)->details->active_slot;
+
 	for (l = providers; l != NULL; l = l->next) {
 		NautilusMenuProvider *provider;
 		GList *file_items;
@@ -151,7 +154,7 @@ get_extension_toolbar_items (NautilusNavigationWindow *window)
 		file_items = nautilus_menu_provider_get_toolbar_items 
 			(provider, 
 			 GTK_WIDGET (window),
-			 NAUTILUS_WINDOW (window)->details->viewed_file);
+			 slot->viewed_file);
 		items = g_list_concat (items, file_items);		
 	}
 
